@@ -16,6 +16,10 @@ class login:
         pass
     
 
+    def build_files():
+        pass
+
+
     def rand_hash(self) -> str:
         "a function to generate random hex-encoded hashes."
         rand_bytes = os.urandom(32)
@@ -53,7 +57,7 @@ class login:
         # getting the hash and salt from cache
         password_hash = contents[0:length:4]; salt = contents[1:length:4]
         # creating the hash object and comparing
-        full_object = password + username.strip() + salt; full_hash = hash.sha256(full_object.encode()); hex_digest = full_hash.hexdigest()
+        full_bytes_obj = PBKDF2(password, salt, dkLen=32); hex_digest = full_bytes_obj.hex()
         # returning values
         if password_hash == hex_digest:
             return 0
@@ -357,3 +361,5 @@ class Main:
 
 
 
+main = Main()
+main.intialize()
\ No newline at end of file
